@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: init_qt.cpp,v 1.23 2007/03/25 20:48:25 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: init_qt.cpp,v 1.24 2007/05/18 20:12:09 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -239,6 +239,16 @@ InstallLangTranslator(void)
        if (trans->load(QStringFromGString(urlb.pathname())))
          qApp->installTranslator(trans);
      }
+   else
+     {
+       GURL urlc = getDjViewDataFile("djview.qm");
+       if (urlc.is_file())
+         {
+           QTranslator *trans = new QTranslator(qApp);
+           if (trans->load(QStringFromGString(urlc.pathname())))
+             qApp->installTranslator(trans);
+         }
+     }
    return true;
 #endif
    return false;
