@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: ByteStream.cpp,v 1.23 2007/03/25 20:48:29 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: ByteStream.cpp,v 1.24 2007/07/14 01:21:56 leonb Exp $
+// $Name: release_3_5_20 $
 
 // From: Leon Bottou, 1/31/2002
 // This file has very little to do with my initial implementation.
@@ -87,7 +87,7 @@
 # endif
 #endif
 
-#if defined(UNIX)
+#ifdef UNIX
 # include <sys/types.h>
 # include <sys/stat.h>
 # include <unistd.h>
@@ -95,13 +95,25 @@
 # ifdef HAS_MEMMAP
 #  include <sys/mman.h>
 # endif
-#elif defined(macintosh)
-# include <unistd.h>
+#endif
+
+#ifdef macintosh
+# ifndef UNIX
+#  include <unistd.h>
 _MSL_IMP_EXP_C int _dup(int);
 _MSL_IMP_EXP_C int _dup2(int,int);
 _MSL_IMP_EXP_C int _close(int);
 __inline int dup(int _a ) { return _dup(_a);}
 __inline int dup2(int _a, int _b ) { return _dup2(_a, _b);}
+# endif
+#endif
+
+#ifdef WIN32
+# if !defined(__MINGW32__) && !defined(__CYGWIN32__)
+#  define close _close
+#  define fdopen _fdopen
+#  define dup _dup
+# endif
 #endif
 
 #ifdef HAVE_NAMESPACES
