@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: ByteStream.h,v 1.15 2007/03/25 20:48:29 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: ByteStream.h,v 1.16 2007/05/19 03:07:33 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _BYTESTREAM_H
 #define _BYTESTREAM_H
@@ -99,7 +99,7 @@
 
 
     @version
-    #$Id: ByteStream.h,v 1.15 2007/03/25 20:48:29 leonb Exp $# */
+    #$Id: ByteStream.h,v 1.16 2007/05/19 03:07:33 leonb Exp $# */
 //@{
 
 
@@ -128,7 +128,7 @@ class GNativeString;
     as private members. It is therefore not possible to make multiple copies
     of instances of this class, as implied by the class semantic.  
 */
-class ByteStream : public GPEnabled
+class DJVUAPI ByteStream : public GPEnabled
 {
 public:
   class Stdio;
@@ -373,7 +373,7 @@ ByteStream::size(void) const
 /** ByteStream::Wrapper implements wrapping bytestream.  This is useful
     for derived classes that take a GP<ByteStream> as a creation argument,
     and the backwards compatible bytestreams.  */
-class ByteStream::Wrapper : public ByteStream
+class DJVUAPI ByteStream::Wrapper : public ByteStream
 {
 protected:
   GP<ByteStream> gbs;
