@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuDocEditor.h,v 1.10 2007/03/25 20:48:30 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: DjVuDocEditor.h,v 1.11 2007/05/19 03:07:33 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _DJVUDOCEDITOR_H
 #define _DJVUDOCEDITOR_H
@@ -84,7 +84,7 @@ namespace DJVU {
 
     @memo DjVu document editor class.
     @author Andrei Erofeev <eaf@geocities.com>
-    @version #$Id: DjVuDocEditor.h,v 1.10 2007/03/25 20:48:30 leonb Exp $#
+    @version #$Id: DjVuDocEditor.h,v 1.11 2007/05/19 03:07:33 leonb Exp $#
 */
 
 //@{
@@ -103,7 +103,7 @@ namespace DJVU {
     \end{enumerate}
 */
 
-class DjVuDocEditor : public DjVuDocument
+class DJVUAPI DjVuDocEditor : public DjVuDocument
 {
 public:
    static int	thumbnails_per_file;
