@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuDocument.cpp,v 1.17 2007/03/25 20:48:30 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: DjVuDocument.cpp,v 1.18 2007/11/26 14:48:34 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -686,19 +686,27 @@ DjVuDocument::page_to_url(int page_num) const
       switch(doc_type)
       {
 	 case SINGLE_PAGE:
+         {
+           if (page_num<1) 
+             url=init_url;
+           break;
+         }
 	 case OLD_INDEXED:
 	 {
-	    if (page_num<0) url=init_url;
-	    else if (flags & DOC_NDIR_KNOWN) url=ndir->page_to_url(page_num);
+	    if (page_num<0) 
+              url=init_url;
+	    else if (flags & DOC_NDIR_KNOWN) 
+              url=ndir->page_to_url(page_num);
 	    break;
 	 }
 	 case OLD_BUNDLED:
 	 {
-	    if (page_num<0) page_num=0;
+	    if (page_num<0) 
+              page_num=0;
 	    if (page_num==0 && (flags & DOC_DIR_KNOWN))
-	       url=GURL::UTF8(first_page_name,init_url);
+              url=GURL::UTF8(first_page_name,init_url);
 	    else if (flags & DOC_NDIR_KNOWN)
-	       url=ndir->page_to_url(page_num);
+              url=ndir->page_to_url(page_num);
 	    break;
 	 }
 	 case BUNDLED:
@@ -708,7 +716,8 @@ DjVuDocument::page_to_url(int page_num) const
 	    if (flags & DOC_DIR_KNOWN)
 	    {
 	      GP<DjVmDir::File> file=djvm_dir->page_to_file(page_num);
-	      if (!file) G_THROW( ERR_MSG("DjVuDocument.big_num") );
+	      if (!file) 
+                G_THROW( ERR_MSG("DjVuDocument.big_num") );
 	      url=GURL::UTF8(file->get_load_name(),init_url);
 	    }
 	    break;
