@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuDocument.h,v 1.11 2007/03/25 20:48:30 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: DjVuDocument.h,v 1.12 2007/05/19 03:07:33 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _DJVUDOCUMENT_H
 #define _DJVUDOCUMENT_H
@@ -92,7 +92,7 @@ class ByteStream;
 
     @memo DjVu document class.
     @author Andrei Erofeev <eaf@geocities.com>
-    @version #$Id: DjVuDocument.h,v 1.11 2007/03/25 20:48:30 leonb Exp $#
+    @version #$Id: DjVuDocument.h,v 1.12 2007/05/19 03:07:33 leonb Exp $#
 */
 
 //@{
@@ -213,7 +213,7 @@ class ByteStream;
 	     \end{itemize}
     \end{enumerate} */
     
-class DjVuDocument : public DjVuPort
+class DJVUAPI DjVuDocument : public DjVuPort
 {
 public:
       /** Flags describing the document initialization state.
