@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuMessage.cpp,v 1.19 2007/03/25 20:48:30 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: DjVuMessage.cpp,v 1.21 2007/07/29 16:23:51 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -77,9 +77,11 @@
 #include <stdlib.h>
 #ifdef WIN32
 # include <tchar.h>
-# include <atlbase.h>
 # include <windows.h>
 # include <winreg.h>
+# ifndef __MINGW32__
+#  include <atlbase.h>
+# endif
 #endif
 #ifdef UNIX
 # include <unistd.h>
@@ -151,34 +153,42 @@ static GURL
 RegOpenReadConfig ( HKEY hParentKey )
 {
   GURL retval;
-   // To do:  This needs to be shared with SetProfile.cpp
   LPCTSTR path = registrypath;
-
   HKEY hKey = 0;
-  // MultiByteToWideChar(CP_ACP,MB_PRECOMPOSED,argv[1],strlen(argv[1])+1,wszSrcFile,sizeof(wszSrcFile));
   if (RegOpenKeyEx(hParentKey, path, 0,
-              KEY_READ, &hKey) == ERROR_SUCCESS )
+		   KEY_READ, &hKey) == ERROR_SUCCESS )
   {
+#ifndef __MINGW32__
     TCHAR path[1024];
-    // Success
     TCHAR *szPathValue = path;
     LPCTSTR lpszEntry = (LPCTSTR &)TEXT("");
     DWORD dwCount = (sizeof(path)/sizeof(TCHAR))-1;
     DWORD dwType;
-
     LONG lResult = RegQueryValueEx(hKey, lpszEntry, NULL,
              &dwType, (LPBYTE) szPathValue, &dwCount);
-
     RegCloseKey(hKey);
-
     if ((lResult == ERROR_SUCCESS))
     {
       szPathValue[dwCount] = 0;
       USES_CONVERSION;
       retval=GURL::Filename::Native(T2CA(path));
     }
+#else
+    CHAR path[1024];
+    CHAR *szPathValue = path;
+    LPCSTR lpszEntry = "";
+    DWORD dwCount = (sizeof(path)/sizeof(CHAR))-1;
+    DWORD dwType;
+    LONG lResult = RegQueryValueExA(hKey, lpszEntry, NULL,
+			&dwType, (LPBYTE)szPathValue, &dwCount);
+    RegCloseKey(hKey);
+    if ((lResult == ERROR_SUCCESS))
+    {
+      szPathValue[dwCount] = 0;
+      retval=GURL::Filename::Native(path);
+    }
+#endif
   } 
-//  if (hKey)  RegCloseKey(hKey); 
   return retval;
 }
 
@@ -186,11 +196,18 @@ static GURL
 GetModulePath( void )
 {
   const GUTF8String cwd(GOS::cwd());
+#ifndef __MINGW32__
   TCHAR path[1024];
   DWORD dwCount = (sizeof(path)/sizeof(TCHAR))-1;
   GetModuleFileName(0, path, dwCount);
   USES_CONVERSION;
   GURL retval=GURL::Filename::Native(T2CA(path)).base();
+#else
+  CHAR path[1024];
+  DWORD dwCount = (sizeof(path)/sizeof(CHAR))-1;
+  GetModuleFileNameA(0, path, dwCount);
+  GURL retval=GURL::Filename::Native(path).base();
+#endif
   GOS::cwd(cwd);
   return retval;
 }
@@ -292,6 +309,7 @@ DjVuMessage::GetProfilePaths(void)
       appendPath(GURL::UTF8(DebugModuleDjVuDir,mpath),pathsmap,paths);
 #endif
       appendPath(mpath,pathsmap,paths);
+      appendPath(GURL::UTF8(ModuleDjVuDir,mpath),pathsmap,paths);
       mpath=mpath.base();
       appendPath(GURL::UTF8(ModuleDjVuDir,mpath),pathsmap,paths);
       mpath=mpath.base();
