@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: DjVuPort.h,v 1.9 2007/03/25 20:48:31 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: DjVuPort.h,v 1.11 2007/07/14 01:21:56 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _DJVUPORT_H
 #define _DJVUPORT_H
@@ -121,7 +121,7 @@ class DataPool;
     @memo DjVu decoder communication mechanism.
     @author Andrei Erofeev <eaf@geocities.com>\\
             L\'eon Bottou <leonb@research.att.com>
-    @version #$Id: DjVuPort.h,v 1.9 2007/03/25 20:48:31 leonb Exp $# */
+    @version #$Id: DjVuPort.h,v 1.11 2007/07/14 01:21:56 leonb Exp $# */
 //@{
 
 class DjVuPort;
@@ -140,7 +140,7 @@ class DjVuFile;
     Ports which are not secured by a smart-pointer are not considered
     ``alive'' and never receive notifications! */
 
-class DjVuPort : public GPEnabled
+class DJVUAPI DjVuPort : public GPEnabled
 {
 public:
    DjVuPort();
@@ -264,7 +264,8 @@ public:
    class DjVuPortCorpse;
 private:
    static GCriticalSection	* corpse_lock;
-   static DjVuPortCorpse	* corpse_head, * corpse_tail;
+   static DjVuPortCorpse	* corpse_head;
+   static DjVuPortCorpse        * corpse_tail;
    static int			corpse_num;
 };
 
@@ -275,7 +276,7 @@ private:
     files) and display error messages on #stderr#.  All other notifications
     are ignored. */
 
-class DjVuSimplePort : public DjVuPort
+class DJVUAPI DjVuSimplePort : public DjVuPort
 {
 public:
       /// Returns 1 if #class_name# is #"DjVuPort"# or #"DjVuSimplePort"#.
@@ -300,7 +301,7 @@ public:
     pool># as needed need and add a route from a \Ref{DjVuDocument} or
     \Ref{DjVuFile} to this port. */
 
-class DjVuMemoryPort : public DjVuPort
+class DJVUAPI DjVuMemoryPort : public DjVuPort
 {
 public:
       /// Returns 1 if #class_name# is #"DjVuPort"# or #"DjVuMemoryPort"#
@@ -355,7 +356,7 @@ private:
 
     The user is not expected to create the #DjVuPortcaster# itself. He should
     use \Ref{get_portcaster}() global function instead.  */
-class DjVuPortcaster
+class DJVUAPI DjVuPortcaster
 {
 public:
       /**  Use this function to get a copy of the global \Ref{DjVuPortcaster}. */
