@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GContainer.h,v 1.19 2007/03/25 20:48:31 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: GContainer.h,v 1.20 2007/05/19 03:07:33 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _GCONTAINER_H_
 #define _GCONTAINER_H_
@@ -132,7 +132,7 @@ namespace DJVU {
     L\'eon Bottou <leonb@research.att.com> -- initial implementation.\\
     Andrei Erofeev <eaf@geocities.com> -- bug fixes.
     @version 
-    #$Id: GContainer.h,v 1.19 2007/03/25 20:48:31 leonb Exp $# */
+    #$Id: GContainer.h,v 1.20 2007/05/19 03:07:33 leonb Exp $# */
 //@{
 
 
@@ -388,7 +388,7 @@ GCONT NormTraits<T>::traits()
     @memo Dynamic arrays.  */
 //@{
 
-class GArrayBase : public GCont
+class DJVUAPI GArrayBase : public GCont
 {
 public:
   // -- CONSTRUCTORS
@@ -763,7 +763,7 @@ public:
     (using member function #del# or by other means.)
 */
 
-class GPosition : protected GCont
+class DJVUAPI GPosition : protected GCont
 {
 public:
   /** Creates a null GPosition object. */
@@ -804,7 +804,7 @@ protected:
 };
 
 
-class GListBase : public GCont
+class DJVUAPI GListBase : public GCont
 {
 protected:
   GListBase(const Traits& traits);
@@ -1073,7 +1073,7 @@ public:
 */
 //@{
 
-class GSetBase : public GCont
+class DJVUAPI GSetBase : public GCont
 {
 protected:
   GSetBase(const Traits &traits);
