@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GOS.cpp,v 1.14 2007/03/25 20:48:32 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: GOS.cpp,v 1.16 2007/07/14 01:21:56 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -75,7 +75,6 @@
 #include <string.h>
 
 #ifdef WIN32
-# include <atlbase.h>
 # include <windows.h>
 # include <direct.h>
 #endif
@@ -97,11 +96,20 @@
 #endif
 
 #ifdef macintosh
-# include <unix.h>
-# include <errno.h>
-# include <unistd.h>
+# ifndef UNIX
+#  include <unix.h>
+#  include <errno.h>
+#  include <unistd.h>
+# endif
 #endif
 
+#ifdef WIN32
+# if !defined(__MINGW32__) && !defined(__CYGWIN32__)
+#  define getcwd _getcwd
+# endif
+#endif
+
+
 // -- TRUE FALSE
 #undef TRUE
 #undef FALSE
