@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GSmartPointer.h,v 1.13 2007/03/25 20:48:32 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: GSmartPointer.h,v 1.14 2007/05/19 03:07:33 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _GSMARTPOINTER_H_
 #define _GSMARTPOINTER_H_
@@ -88,7 +88,7 @@
 // <http://prdownloads.sourceforge.net/djvu/DjVu2_2b-src.tgz>.
 
     @version 
-    #$Id: GSmartPointer.h,v 1.13 2007/03/25 20:48:32 leonb Exp $# 
+    #$Id: GSmartPointer.h,v 1.14 2007/05/19 03:07:33 leonb Exp $# 
     @args
 */
 //@{
@@ -115,7 +115,7 @@ namespace DJVU {
     Any instance of a subclass of #GPEnabled# can be used with 
     smart-pointers (see \Ref{GP}).  
  */
-class GPEnabled
+class DJVUAPI GPEnabled
 {
 public:
   /// Null constructor.
@@ -148,7 +148,7 @@ private:
     in reducing the template expansion overhead.
 */
 
-class GPBase
+class DJVUAPI GPBase
 {
 public:
   /** Null Constructor. */
@@ -458,7 +458,7 @@ GP<TYPE>::operator! () const
    What does it do that a GArray does not do ? 
    What about the objects construction and destruction ? */
 
-class GPBufferBase
+class DJVUAPI GPBufferBase
 {
 public:
   GPBufferBase(void *&,const size_t n,const size_t t);
