@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 //
-// $Id: GString.h,v 1.21 2007/03/25 20:48:32 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: GString.h,v 1.23 2007/07/29 16:23:51 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _GSTRING_H_
 #define _GSTRING_H_
@@ -105,7 +105,7 @@
 // This could be fixed.  But there are better things to do in djvulibre.
     
     @version
-    #$Id: GString.h,v 1.21 2007/03/25 20:48:32 leonb Exp $# */
+    #$Id: GString.h,v 1.23 2007/07/29 16:23:51 leonb Exp $# */
 //@{
 
 
@@ -145,7 +145,7 @@ class GUTF8String;
 class GNativeString;
 
 // Internal string representation.
-class GStringRep : public GPEnabled
+class DJVUAPI GStringRep : public GPEnabled
 {
 public:
   enum EncodeType { XUCS4, XUCS4BE, XUCS4LE, XUCS4_2143, XUCS4_3412,
@@ -366,7 +366,7 @@ protected:
   char *data;
 };
 
-class GStringRep::UTF8 : public GStringRep
+class DJVUAPI GStringRep::UTF8 : public GStringRep
 {
 public:
   // default constructor
@@ -463,7 +463,7 @@ protected:
     position #-1# accesses the last character of the string,
     position #-2# represents the second last character, etc.)  */
 
-class GBaseString : protected GP<GStringRep>
+class DJVUAPI GBaseString : protected GP<GStringRep>
 {
 public:
   enum EscapeMode {
@@ -475,10 +475,10 @@ public:
   friend class GNativeString;
 protected:
   // Sets the gstr pointer;
-  void init(void);
+  inline void init(void);
 
   ~GBaseString();
-  GBaseString &init(const GP<GStringRep> &rep);
+  inline GBaseString &init(const GP<GStringRep> &rep);
 
   // -- CONSTRUCTORS
   /** Null constructor. Constructs an empty string. */
@@ -711,7 +711,7 @@ public:
     const EscapeMode escape=UNKNOWN_ESCAPED) const;
   GUTF8String NativeToUTF8(void) const;
 protected:
-  int CheckSubscript(int n) const;
+  inline int CheckSubscript(int n) const;
 };
 
 /** General purpose character string.
@@ -735,13 +735,13 @@ protected:
     position #-1# accesses the last character of the string,
     position #-2# represents the second last character, etc.)  */
 
-class GUTF8String : public GBaseString
+class DJVUAPI GUTF8String : public GBaseString
 {
 public:
   ~GUTF8String();
-  void init(void);
+  inline void init(void);
 
-  GUTF8String &init(const GP<GStringRep> &rep);
+  inline GUTF8String &init(const GP<GStringRep> &rep);
 
   // -- CONSTRUCTORS
   /** Null constructor. Constructs an empty string. */
@@ -778,10 +778,10 @@ public:
       character array #str#. */
   GUTF8String& operator= (const char str);
   GUTF8String& operator= (const char *str);
-  GUTF8String& operator= (const GP<GStringRep> &str);
-  GUTF8String& operator= (const GBaseString &str);
-  GUTF8String& operator= (const GUTF8String &str);
-  GUTF8String& operator= (const GNativeString &str);
+  inline GUTF8String& operator= (const GP<GStringRep> &str);
+  inline GUTF8String& operator= (const GBaseString &str);
+  inline GUTF8String& operator= (const GUTF8String &str);
+  inline GUTF8String& operator= (const GNativeString &str);
 
   /** Constructs a string with a formatted string (as in #vprintf#).
       The string is re-initialized with the characters generated
@@ -937,7 +937,7 @@ public:
     position #-1# accesses the last character of the string,
     position #-2# represents the second last character, etc.)  */
 
-class GNativeString : public GBaseString
+class DJVUAPI GNativeString : public GBaseString
 {
 public:
   ~GNativeString();
@@ -1005,10 +1005,10 @@ public:
       array #str#. */
   GNativeString& operator= (const char str);
   GNativeString& operator= (const char *str);
-  GNativeString& operator= (const GP<GStringRep> &str);
-  GNativeString& operator= (const GBaseString &str);
-  GNativeString& operator= (const GUTF8String &str);
-  GNativeString& operator= (const GNativeString &str);
+  inline GNativeString& operator= (const GP<GStringRep> &str);
+  inline GNativeString& operator= (const GBaseString &str);
+  inline GNativeString& operator= (const GUTF8String &str);
+  inline GNativeString& operator= (const GNativeString &str);
   // -- CONCATENATION
   /// Appends character #ch# to the string.
   GNativeString& operator+= (char ch);
