@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: GURL.cpp,v 1.24 2007/03/25 20:48:32 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: GURL.cpp,v 1.27 2007/11/26 15:11:05 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -82,9 +82,12 @@
 #include <string.h>
 
 #ifdef WIN32
-# include <atlbase.h>
+# include <tchar.h>
 # include <windows.h>
 # include <direct.h>
+# ifndef __MINGW32__
+#  include <atlbase.h>
+# endif
 #endif /* WIN32 */
 
 // -- MAXPATHLEN
@@ -483,12 +486,14 @@ GURL::operator=(const GURL & url_in)
 GUTF8String
 GURL::protocol(const GUTF8String& url)
 {
-   const char * const url_ptr=url;
-   const char * ptr=url_ptr;
-   for(char c=*ptr;
-     c && (isalnum(c) || c == '+' || c == '-' || c == '.');
-     c=*(++ptr)) EMPTY_LOOP;
-   return(*ptr==colon)?GUTF8String(url_ptr, ptr-url_ptr):GUTF8String();
+  const char * const url_ptr=url;
+  const char * ptr=url_ptr;
+  for(char c=*ptr;
+      c && (isalnum(c) || c == '+' || c == '-' || c == '.');
+      c=*(++ptr)) EMPTY_LOOP;
+  if (ptr[0]==colon && ptr[1]=='/' && ptr[2]=='/')
+    return GUTF8String(url_ptr, ptr-url_ptr);
+  return GUTF8String();
 }
 
 GUTF8String
@@ -1099,7 +1104,7 @@ GURL::encode_reserved(const GUTF8String &gs)
     if ( (ss>='a' && ss<='z') ||
          (ss>='A' && ss<='Z') ||
          (ss>='0' && ss<='9') ||
-         (strchr("$-_.+!*'(),:~=", ss)) ) 
+         (strchr("$-_.+!*'(),~:=", ss)) ) 
     {
       *d = ss;
       continue;
@@ -1414,8 +1419,12 @@ GURL::is_file(void) const
     dwAttrib = GetFileAttributesW(wfilename);
     if((dwAttrib|1) == 0xFFFFFFFF)
       {
+#ifdef __MINGW32__
+        dwAttrib = GetFileAttributesA(NativeFilename());
+#else
         USES_CONVERSION ;
         dwAttrib = GetFileAttributes(A2CT(NativeFilename())) ;//MBCS cvt
+#endif
       }
     retval=!( dwAttrib & FILE_ATTRIBUTE_DIRECTORY );
 #else
@@ -1451,8 +1460,12 @@ GURL::is_local_path(void) const
     dwAttrib = GetFileAttributesW(wfilename);
     if((dwAttrib|1) == 0xFFFFFFFF)
       {
+#ifdef __MINGW32__
+        dwAttrib = GetFileAttributesA(NativeFilename());
+#else
         USES_CONVERSION ;
         dwAttrib = GetFileAttributes(A2CT(NativeFilename())) ;//MBCS cvt
+#endif
       }
     retval=( (dwAttrib|1) != 0xFFFFFFFF);
 #endif
@@ -1492,8 +1505,12 @@ GURL::is_dir(void) const
     dwAttrib = GetFileAttributesW(wfilename);
     if((dwAttrib|1) == 0xFFFFFFFF)
       {
+#ifdef __MINGW32__
+        dwAttrib = GetFileAttributesA(NativeFilename());
+#else
         USES_CONVERSION ;
         dwAttrib = GetFileAttributes(A2CT(NativeFilename())) ;//MBCS cvt
+#endif
       }
     retval=((dwAttrib != 0xFFFFFFFF)&&( dwAttrib & FILE_ATTRIBUTE_DIRECTORY ));
 #else
@@ -1543,11 +1560,18 @@ GURL::mkdir() const
       else 
         retval = ::mkdir(NativeFilename(), 0755);
 #elif defined(WIN32)
+# ifdef __MINGW32__
+      if (is_dir())
+        retval = 0;
+      else 
+        retval = CreateDirectoryA(NativeFilename(), NULL);
+# else
       USES_CONVERSION;
       if (is_dir())
         retval = 0;
       else 
         retval = CreateDirectory(A2CT(NativeFilename()), NULL);
+# endif
 #else
 # error "Define something here for your operating system"
 #endif
@@ -1570,11 +1594,18 @@ GURL::deletefile(void) const
       else
         retval = ::unlink(NativeFilename());
 #elif defined(WIN32)
+# ifdef __MINGW32__
+      if (is_dir())
+        retval = ::RemoveDirectoryA(NativeFilename());
+      else
+        retval = ::DeleteFile(NativeFilename());
+# else
       USES_CONVERSION;
       if (is_dir())
         retval = ::RemoveDirectory(A2CT(NativeFilename()));
       else
         retval = ::DeleteFile(A2CT(NativeFilename()));
+# endif
 #else
 # error "Define something here for your operating system"
 #endif
