@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: JB2Image.h,v 1.11 2007/03/25 20:48:32 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: JB2Image.h,v 1.12 2007/05/19 03:07:34 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifndef _JB2IMAGE_H
 #define _JB2IMAGE_H
@@ -158,7 +158,7 @@
     \end{itemize}
 
     @version
-    #$Id: JB2Image.h,v 1.11 2007/03/25 20:48:32 leonb Exp $#
+    #$Id: JB2Image.h,v 1.12 2007/05/19 03:07:34 leonb Exp $#
     @memo
     Coding bilevel images with JB2.
     @author
@@ -249,7 +249,7 @@ typedef GP<JB2Dict> JB2DecoderCallback ( void* );
 
 /** Dictionary of JB2 shapes. */
 
-class JB2Dict : public GPEnabled
+class DJVUAPI JB2Dict : public GPEnabled
 {
 protected:
   JB2Dict(void);
@@ -344,7 +344,7 @@ private:
     to render anti-aliased images, or use function \Ref{encode} to generate
     JB2 data. */
 
-class JB2Image : public JB2Dict
+class DJVUAPI JB2Image : public JB2Dict
 {
 protected:
   JB2Image(void);
