@@ -54,7 +54,7 @@
 //C- +------------------------------------------------------------------
 */
 
-/* $Id: ddjvuapi.h,v 1.61 2007/03/25 20:48:35 leonb Exp $ */
+/* $Id: ddjvuapi.h,v 1.62 2007/05/19 03:07:34 leonb Exp $ */
 
 #ifndef DDJVUAPI_H
 #define DDJVUAPI_H
@@ -69,12 +69,23 @@ extern "C" {
 #include <stdlib.h>
 #include <stdio.h>
 
+#ifndef DDJVUAPI
+# ifdef WIN32
+#  ifdef DLL_EXPORT
+#   define DDJVUAPI __declspec(dllexport)
+#  else
+#   define DDJVUAPI __declspec(dllimport)
+#  endif
+# endif
+#endif
 #ifndef DDJVUAPI
 # define DDJVUAPI /**/
 #endif
+
 #ifndef TRUE
 # define TRUE  (1)
 #endif
+
 #ifndef FALSE
 # define FALSE (0)
 #endif
