@@ -15,7 +15,7 @@
 // GNU General Public License for more details.
 // -------------------------------------------------------------------
 */
-/* $Id: miniexp.cpp,v 1.14 2007/03/25 20:48:35 leonb Exp $ */
+/* $Id: miniexp.cpp,v 1.15 2007/11/09 19:04:22 leonb Exp $ */
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -672,7 +672,7 @@ miniobj_t::~miniobj_t()
 {
 }
 
-miniexp_t miniobj_t::classname = 0;
+const miniexp_t miniobj_t::classname = 0;
 
 bool
 miniobj_t::isa(miniexp_t) const
