@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 // 
-// $Id: csepdjvu.cpp,v 1.21 2007/03/25 20:48:35 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: csepdjvu.cpp,v 1.26 2007/09/29 17:51:43 leonb Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -136,7 +136,7 @@
     @author
     L\'eon Bottou <leonb@research.att.com>
     @version
-    #$Id: csepdjvu.cpp,v 1.21 2007/03/25 20:48:35 leonb Exp $# */
+    #$Id: csepdjvu.cpp,v 1.26 2007/09/29 17:51:43 leonb Exp $# */
 //@{
 //@}
 
@@ -154,12 +154,15 @@
 #include "IW44Image.h"
 #include "DjVuInfo.h"
 #include "DjVmDoc.h"
+#include "DjVmNav.h"
 #include "GOS.h"
 #include "GURL.h"
 #include "DjVuMessage.h"
 #include "DjVuText.h"
 #include "BSByteStream.h"
 
+#include "miniexp.h"
+
 #include "jb2tune.h"
 
 #include <locale.h>
@@ -595,7 +598,7 @@ CRLEImage::CRLEImage(BufferByteStream &bs)
           if (x >= 0xc0)
             x = (bs.get()) + ((x - 0xc0) << 8);
           if (c+x > width)
-            G_THROW("csepdjvu: corrupted input file (lost RLE synchronization)");
+            G_THROW("csepdjvu: corrupted input file (lost RLE sync.)");
           if (p)
             {
               px[0] = c;
@@ -640,7 +643,7 @@ CRLEImage::CRLEImage(BufferByteStream &bs)
           p = (x >> 20) & 0xfff;
           x = (x & 0xfffff);
           if (c+x > width)
-            G_THROW("csepdjvu: corrupted input file (lost RLE synchronization)");
+            G_THROW("csepdjvu: corrupted input file (lost RLE sync.)");
           if (p >= 0 && p < ncolors)
             {
               px[0] = c;
@@ -1093,6 +1096,7 @@ public:
   void process_comments(BufferByteStream &bs, int verbose=0);
   bool parse_comment_line(BufferByteStream &bs);
   void make_chunks(IFFByteStream &iff);
+  GP<DjVmNav> get_djvm_nav();
 protected:
   int w;
   int h;
@@ -1109,6 +1113,12 @@ protected:
   };
   GPList<TxtMark> lastline;
   GP<DjVuTXT> txt;
+  struct LnkMark : public GPEnabled {
+    GRect r;
+    GUTF8String s;
+  };
+  GPList<LnkMark> links;
+  GP<DjVmNav> nav;
 protected:
   bool allspace(const TxtMark *mark);
   void textmark(GP<TxtMark> mark);
@@ -1185,6 +1195,38 @@ Comments::parse_comment_line(BufferByteStream &bs)
       textmark(mark);
       return true;
     }
+  // Link comments
+  if (c == 'L')
+    {
+      GP<LnkMark> mark = new LnkMark;
+      if (! (bs.skip(" \t") && bs.read_geometry(mark->r) &&
+             bs.skip(" \t") && bs.read_ps_string(mark->s) ) )
+        G_THROW("csepdjvu: corrupted file (syntax error in link comment)");
+      int ymax = h - mark->r.ymin - 1; // reversed in gsdjvu ?
+      int ymin = h - mark->r.ymax - 1; // reversed in gsdjvu ?
+      mark->r.ymax = ymax;
+      mark->r.ymin = ymin;
+      links.append(mark);
+      return true;
+    }
+  // Bookmark comments
+  if (c == 'B')
+    {
+      int count; 
+      GUTF8String url;
+      GUTF8String title;
+      if (! (bs.skip(" \t") && bs.read_integer(count) &&
+             bs.skip(" \t") && bs.read_ps_string(title) &&
+             bs.skip(" \t") && bs.read_ps_string(url) ) )
+        G_THROW("csepdjvu: corrupted file (syntax error in outline comment)");
+      GP<DjVmNav::DjVuBookMark> b = 
+        DjVmNav::DjVuBookMark::create(count, title, url);
+      if (b && ! nav)
+        nav = DjVmNav::create();
+      if (b)
+        nav->append(b);
+      return true;
+    }
   // Unrecognized
   bs.unget(c);
   return false;
@@ -1332,7 +1374,8 @@ Comments::textflush(void)
                   wzone->ztype = DjVuTXT::WORD;
                   wzone->text_start = txt->textUTF8.length();
                   txt->textUTF8 += word->s;
-                  wzone->text_length = txt->textUTF8.length() - wzone->text_start;
+                  wzone->text_length = 
+                    txt->textUTF8.length() - wzone->text_start;
                   wzone->rect = word->r;
                   lzone->rect.recthull(lzone->rect, word->r);
                 }
@@ -1340,7 +1383,8 @@ Comments::textflush(void)
                 {
                   if (lzone->text_length > 0) txt->textUTF8 += " ";
                   txt->textUTF8 += word->s;
-                  lzone->text_length = txt->textUTF8.length() - lzone->text_start;
+                  lzone->text_length = 
+                    txt->textUTF8.length() - lzone->text_start;
                   lzone->rect.recthull(lzone->rect, word->r);
                 }
             }
@@ -1349,6 +1393,16 @@ Comments::textflush(void)
   lastline.empty();
 }
 
+static ByteStream *minilisp_outbs = 0;
+
+static int 
+minilisp_outfunc(const char *s)
+{
+  if (minilisp_outbs)
+    return minilisp_outbs->write((const void*)s, strlen(s));
+  return -1;
+}
+
 void 
 Comments::make_chunks(IFFByteStream &iff)
 {
@@ -1364,8 +1418,50 @@ Comments::make_chunks(IFFByteStream &iff)
       }
       iff.close_chunk();
     }
+  // Create annotation chunk
+  if (links.size() > 0)
+    {
+      iff.put_chunk("ANTz");
+      {
+        GP<ByteStream> bsb = BSByteStream::create(iff.get_bytestream(), 50);
+        minilisp_outbs = bsb;
+        minilisp_puts = minilisp_outfunc;
+        minivar_t exor = miniexp_cons(miniexp_symbol("xor"),miniexp_nil);
+        for (GPosition p = links; p; ++p)
+          {
+            GP<LnkMark> mark = links[p];
+            minivar_t url = miniexp_string((const char*)(mark->s));
+            minivar_t expr = miniexp_cons(exor, miniexp_nil);
+            minivar_t area;
+            area = miniexp_cons(miniexp_number(mark->r.height()), area);
+            area = miniexp_cons(miniexp_number(mark->r.width()), area);
+            area = miniexp_cons(miniexp_number(mark->r.ymin), area);
+            area = miniexp_cons(miniexp_number(mark->r.xmin), area);
+            area = miniexp_cons(miniexp_symbol("rect"),area);
+            expr = miniexp_cons(area, expr);
+            expr = miniexp_cons(miniexp_nil, expr);
+            expr = miniexp_cons(url, expr);
+            expr = miniexp_cons(miniexp_symbol("maparea"), expr);
+            miniexp_pprint(expr, 72);
+          }
+        minilisp_outbs = 0;
+        minilisp_set_output(stdout);
+      }
+      iff.close_chunk();
+    }
 }
 
+GP<DjVmNav>
+Comments::get_djvm_nav()
+{
+  if (nav && nav->getBookMarkCount() && nav->isValidBookmark())
+    return nav;
+  if (nav)
+    DjVuPrintErrorUTF8("%s", "csepdjvu: corrupted outline comments.\n");
+  return 0;
+}
+
+
 // --------------------------------------------------
 // MAIN COMPRESSION ROUTINE
 // --------------------------------------------------
@@ -1375,7 +1471,10 @@ Comments::make_chunks(IFFByteStream &iff)
 //    - bytestream bs contains the input separated file.
 //    - bytestream obs will receive the output djvu file.
 void 
-csepdjvu_page(BufferByteStream &bs, GP<ByteStream> obs, const csepdjvuopts &opts)
+csepdjvu_page(BufferByteStream &bs, 
+              GP<ByteStream> obs, 
+              GP<DjVmNav> &nav,
+              const csepdjvuopts &opts)
 {
   // Read rle data from separation file
   CRLEImage rimg(bs);
@@ -1390,7 +1489,8 @@ csepdjvu_page(BufferByteStream &bs, GP<ByteStream> obs, const csepdjvuopts &opts
   rimg.make_ccids_by_analysis();                  // Obtain ccids
   rimg.make_ccs_from_ccids();                     // Compute cc descriptors
   if (opts.verbose > 1)
-    DjVuFormatErrorUTF8( "%s\t%d", ERR_MSG("csepdjvu.analyzed"), rimg.ccs.size());
+    DjVuFormatErrorUTF8("%s\t%d", ERR_MSG("csepdjvu.analyzed"), 
+                        rimg.ccs.size());
   
   // Post-process Color Connected Components
   int largesize = MIN(500, MAX(64, opts.dpi));
@@ -1545,6 +1645,9 @@ csepdjvu_page(BufferByteStream &bs, GP<ByteStream> obs, const csepdjvuopts &opts
   // -- terminate main composite chunk
   coms.make_chunks(iff);
   iff.close_chunk();
+  // -- store outline
+  if (! nav) 
+    nav = coms.get_djvm_nav();
 }  
 
 // -- Checks whether there is another page in the same file
@@ -1568,22 +1671,23 @@ check_for_another_page(BufferByteStream &bs, const csepdjvuopts &opts)
 void
 usage()
 {
-  DjVuPrintErrorUTF8(
+  const char *msg = 
 #ifdef DJVULIBRE_VERSION
-         "CSEPDJVU --- DjVuLibre-" DJVULIBRE_VERSION "\n"
+    "CSEPDJVU --- DjVuLibre-" DJVULIBRE_VERSION "\n"
 #endif
-         "DjVu encoder working with \"separated\" files\n\n"
-         "Usage: csepdjvu <...options_or_separatedfiles...> <outputdjvufile>\n"
-         "Options are:\n"
-         "   -v, -vv    Select verbosity level.\n"
-         "   -d <n>     Set resolution to <n> dpi (default: 300).\n"
-         "   -t         Restricts text information to lines only.\n"
-         "   -q <spec>  Select quality level for background (default: 72+11+10+10);\n"
-         "              see option -slice in program c44 for additional information.\n"
-         "Each separated files contain one or more pages\n"
-         "Each page is composed of:\n"
-         " (1) a B&W-RLE or Color-RLE image representing the foreground,\n"
-         " (2) an optional PPM image representing the background layer.\n" );
+    "DjVu encoder working with \"separated\" files\n\n"
+    "Usage: csepdjvu <...options_or_separatedfiles...> <outputdjvufile>\n"
+    "Options are:\n"
+    "   -v, -vv    Select verbosity level.\n"
+    "   -d <n>     Set resolution to <n> dpi (default: 300).\n"
+    "   -t         Restricts text information to lines only.\n"
+    "   -q <spec>  Select quality for background (default: 72+11+10+10);\n"
+    "              see option -slice in program c44 for more information.\n"
+    "Each separated files contain one or more pages\n"
+    "Each page is composed of:\n"
+    " (1) a B&W-RLE or Color-RLE image representing the foreground,\n"
+    " (2) an optional PPM image representing the background layer.\n";
+  DjVuPrintErrorUTF8(msg);
   exit(10);
 }
 
@@ -1599,22 +1703,27 @@ parse_slice(const char *q, csepdjvuopts &opts)
       char *ptr; 
       int x = strtol(q, &ptr, 10);
       if (ptr == q)
-        G_THROW("csepdjvu: illegal quality specification (number expected)");
+        G_THROW("csepdjvu: "
+                "illegal quality specification (number expected)");
       if (lastx>0 && q[-1]=='+')
         x += lastx;
       if (x<1 || x>1000 || x<lastx)
-        G_THROW("csepdjvu: illegal quality specification (number out of range)");
+        G_THROW("csepdjvu: "
+                "illegal quality specification (number out of range)");
       lastx = x;
       if (*ptr && *ptr!='+' && *ptr!=',')
-        G_THROW("csepdjvu: illegal quality specification (comma expected)");        
+        G_THROW("csepdjvu: "
+                "illegal quality specification (comma expected)");        
       q = (*ptr ? ptr+1 : ptr);
       if (count+1 >= (int)(sizeof(opts.slice)/sizeof(opts.slice[0])))
-        G_THROW("csepdjvu: illegal quality specification (too many chunks)");                
+        G_THROW("csepdjvu: "
+                "illegal quality specification (too many chunks)");
       opts.slice[count++] = x;
       opts.slice[count] = 0;
     }
   if (count < 1)
-    G_THROW("csepdjvu: illegal quality specification (no chunks)");                    
+    G_THROW("csepdjvu: "
+            "illegal quality specification (no chunks)");
 }
 
 
@@ -1630,6 +1739,7 @@ main(int argc, const char **argv)
   G_TRY
     {
       GP<DjVmDoc> gdoc=DjVmDoc::create();
+      GP<DjVmNav> gnav;
       DjVmDoc &doc=*gdoc;
       GURL outputurl;
       GP<ByteStream> goutputpage=ByteStream::create();
@@ -1675,42 +1785,46 @@ main(int argc, const char **argv)
           else 
             {
               // Process separation file
-              GP<ByteStream> fbs=ByteStream::create(GURL::Filename::UTF8(arg),"rb");
+              GP<ByteStream> fbs = 
+                ByteStream::create(GURL::Filename::UTF8(arg),"rb");
               BufferByteStream ibs(*fbs);
               do {
                 char pagename[16];
                 sprintf(pagename, "p%04d.djvu", ++pageno);
                 if (opts.verbose > 1)
-                  DjVuPrintErrorUTF8("%s","-------------------------------------\n");
+                  DjVuPrintErrorUTF8("%s","--------------------\n");
                 // Compress page 
                 goutputpage=ByteStream::create();
                 ByteStream &outputpage=*goutputpage;
-                csepdjvu_page(ibs, goutputpage, opts);
+                csepdjvu_page(ibs, goutputpage, gnav, opts);
                 if (opts.verbose) {
                   DjVuPrintErrorUTF8("csepdjvu: %d bytes for page %d",
-                          outputpage.size(), pageno);
+                                     outputpage.size(), pageno);
                   if (arg == "-")
                     DjVuPrintErrorUTF8("%s"," (from stdin)\n");
                   else
-                    DjVuPrintErrorUTF8(" (from file '%s')\n", (const char*)arg);
+                    DjVuPrintErrorUTF8(" (from file '%s')\n", 
+                                       (const char*)arg);
                 }
                 // Insert page into document
                 outputpage.seek(0);
-                doc.insert_file(outputpage, DjVmDir::File::PAGE, pagename, pagename);
+                doc.insert_file(outputpage, DjVmDir::File::PAGE, 
+                                pagename, pagename);
               } while (check_for_another_page(ibs, opts));
             }
         } 
       // Save file
-      if (pageno == 1) 
+      if (pageno == 1 && ! gnav) 
         {
           ByteStream &outputpage=*goutputpage;
           // Save as a single page 
           outputpage.seek(0);
           ByteStream::create(outputurl,"wb")->copy(outputpage);
         }
-      else if (pageno > 1)
+      else if (pageno >= 1)
         {
           // Save as a bundled file
+          doc.set_djvm_nav(gnav);
           doc.write(ByteStream::create(outputurl,"wb"));
         }
       else 
