@@ -53,8 +53,8 @@
 //C- | MERCHANTABILITY OR FITNESS FOR A PARTICULAR PURPOSE.
 //C- +------------------------------------------------------------------
 //
-// $Id: djvumake.cpp,v 1.12 2007/03/25 20:48:36 leonb Exp $
-// $Name: release_3_5_19 $
+// $Id: djvumake.cpp,v 1.13 2007/03/26 04:57:25 bpearlmutter Exp $
+// $Name: release_3_5_20 $
 
 #ifdef HAVE_CONFIG_H
 # include "config.h"
@@ -132,7 +132,7 @@
     @memo
     Assemble DjVu files.
     @version
-    #$Id: djvumake.cpp,v 1.12 2007/03/25 20:48:36 leonb Exp $#
+    #$Id: djvumake.cpp,v 1.13 2007/03/26 04:57:25 bpearlmutter Exp $#
     @author
     L\'eon Bottou <leonb@research.att.com> \\
     Patrick Haffner <haffner@research.att.com>
@@ -531,7 +531,7 @@ create_bg44_chunk(IFFByteStream &iff, char *ckid, GUTF8String filespec)
       if (chkid != "FORM:PM44" && chkid != "FORM:BM44")
         G_THROW("djvumake: BG44 file has incorrect format (wrong IFF header)");        
       if (i>=0)
-        filespec = i+(const char *)filespec;
+        filespec = i+1+(const char *)filespec;
       else 
         filespec = "99";
     }
